@@ -236,31 +236,7 @@ class DobViewerConfigurableDev(object):
         _("XXX"),
     )
     def jump_rift_dec(self):
-        return json.dumps([('g', 'g')])
-
-    # ***
-
-    @property
-    @ConfigRoot.setting(
-        _("XXX"),
-    )
-    def jump_rift_inc(self):
-        return 'G'
-
-    # ***
-
-    @property
-    @ConfigRoot.setting(
-        _("XXX"),
-    )
-    def jump_fact_first(self):
-        # 2020-04-14: (lb): The original 'G' and 'gg' commands sorta morphed
-        # into the "rift" jumpers, which stop on the boundaries of the
-        # FactsManager groups. But we really should have a true Home/End Fact
-        # command.
-        # - (lb): Let's try 'f' and 'F' for the final/First Fact jumpers.
-        #   I realize this might conflict later with a potential 'f'ind
-        #   command... but the '/' mapping (Vim's find) is still available.
+        # A good pneumonic: 'F'irst Fact.
         return 'F'
 
     # ***
@@ -269,11 +245,30 @@ class DobViewerConfigurableDev(object):
     @ConfigRoot.setting(
         _("XXX"),
     )
-    def jump_fact_final(self):
+    def jump_rift_inc(self):
+        # A good pneumonic: 'f'inal Fact.
         return 'f'
 
     # ***
 
+    @property
+    @ConfigRoot.setting(
+        _("XXX"),
+    )
+    def jump_fact_first(self):
+        return json.dumps([('g', 'g')])
+
+    # ***
+
+    @property
+    @ConfigRoot.setting(
+        _("XXX"),
+    )
+    def jump_fact_final(self):
+        return 'G'
+
+    # ***
+
     @property
     @ConfigRoot.setting(
         _("XXX"),
@@ -333,7 +328,7 @@ class DobViewerConfigurableDev(object):
         _("XXX"),
     )
     def edit_fact(self):
-        # Raw Fact Editing. With a Capital E.
+        # Edit merry-go-round: Prompt for act@gory, then tags, then description.
         return 'E'
 
     # ***
@@ -690,6 +685,49 @@ class DobViewerConfigurableDev(object):
 
     # ***
 
+    # Command shortcuts.
+
+    # 2020-04-15: (lb): I did not consider much before picking the
+    # key bindings below. There are not any obvious mappings, other
+    # than perhaps (a) avoiding keys that have universal mappings
+    # (like Ctrl-c, Ctrl-q, etc.). Also (b) making it easy to press
+    # (i.e., not Ctrl-g), as these may be used often.
+    # - I suppose between 'c-e' and 'V', on an English keyboard, they
+    #   are similar motions (pinky plus pointer), so maybe that'll
+    #   help people remember. And 'o' is pretty baked in from Vim.
+    #   Open a new fact -- and prompt for the act@gory.
+
+    @property
+    @ConfigRoot.setting(
+        _("XXX"),
+    )
+    def copy_complete_and_paste_active(self):
+        return 'c-e'
+
+    # ***
+
+    @property
+    @ConfigRoot.setting(
+        _("XXX"),
+    )
+    def copy_complete_and_paste_new(self):
+        return 'V'
+
+    # ***
+
+    @property
+    @ConfigRoot.setting(
+        _("XXX"),
+    )
+    def complete_and_prompt_new(self):
+        # 'a' for act@gory, like plain 'a' command mapping.
+        # Or not. 'c-a' is a common tmux prefix key.
+        #  return 'c-a'
+        # How 'bout, 'o'pen a new entry?
+        return 'o'
+
+    # ***
+
 
 # ***
 
@@ -730,3 +768,48 @@ def json_load_sublisted(cfgname, cfgval):
 
     return _json_load_sublisted()
 
+
+# ***
+
+@ConfigRoot.section('custom-paste')
+class DobViewerCustomPaste(object):
+    """"""
+
+    def __init__(self, *args, **kwargs):
+        pass
+
+    # ***
+
+    # (lb): This is the best I've got on a moment's thought:
+    # Create placeholder config so that it'll be read from user's dob.conf.
+    # (lb): This is not the cleanest solutions (we have to arbitrarily decide how
+    # many placeholders to create), but it's otherwise transparent to the user.
+
+    def add_custom_paste(postfix):
+        """"""
+        factoid_name = 'factoid_{}'.format(postfix)
+        mapping_name = 'mapping_{}'.format(postfix)
+
+        @property
+        @ConfigRoot.setting(
+            _("XXX"),
+            name=factoid_name,
+            hidden=True,
+        )
+        def factoid_prop(self):
+            return ''
+
+        @property
+        @ConfigRoot.setting(
+            _("XXX"),
+            name=mapping_name,
+            hidden=True,
+        )
+        def mapping_prop(self):
+            return ''
+
+    A_PERFECT_NUMBER = 28
+
+    for postfix in range(1, A_PERFECT_NUMBER):
+        add_custom_paste(postfix)
+
