@@ -333,8 +333,9 @@ class Carousel(object):
     def standup_always(self, **kwargs):
         self.zone_manager = ZoneManager(self)
         self.zone_manager.standup()
-        self.update_handler.standup()
         self.action_manager.standup()
+        self.update_handler.standup()
+        self.action_manager.finalize_standup()  # Prints key binding errors.
         self.zone_manager.build_and_show(**kwargs)
 
     # ***
@@ -543,6 +544,7 @@ class Carousel(object):
                 self.controller,
                 saved_facts,
                 show_plugin_error=self.show_plugin_error,
+                carousel_active=True,
             )
         edit_cnt = len(saved_facts)
         self.zone_manager.finalize_jump(
